Learn R Programming

tfruns (version 0.9.1)

training_run: Run a training script

Description

Run a training script

Usage

training_run(file = "train.R", type = "local",
  config = Sys.getenv("R_CONFIG_ACTIVE", unset = "default"), flags = NULL,
  properties = NULL, run_dir = NULL, echo = FALSE,
  envir = parent.frame(), encoding = getOption("encoding"))

Arguments

file

Path to training script (defaults to "train.R")

type

Run type (defaults to "local")

config

The configuration to use. Defaults to the active configuration for the current environment (as specified by the R_CONFIG_ACTIVE environment variable), or default when unset.

flags

Named character vector with flag values (see flags()) or path to YAML file containing flag values.

properties

Named character vector with run properties. Properties are additional metadata about the run which will be subsequently available via ls_runs().

run_dir

Directory to store run data within

echo

Print expressions within training script

envir

The environment in which the script should be evaluated

encoding

The encoding of the training script; see file().

Value

Single row data frame with run flags, metrics, etc.