Run a training script
training_run(file = "train.R", type = "local",
config = Sys.getenv("R_CONFIG_ACTIVE", unset = "default"), flags = NULL,
properties = NULL, run_dir = NULL, echo = FALSE,
envir = parent.frame(), encoding = getOption("encoding"))Path to training script (defaults to "train.R")
Run type (defaults to "local")
The configuration to use. Defaults to the active configuration
for the current environment (as specified by the R_CONFIG_ACTIVE
environment variable), or default when unset.
Named character vector with flag values (see flags()) or path
to YAML file containing flag values.
Named character vector with run properties. Properties are
additional metadata about the run which will be subsequently available via
ls_runs().
Directory to store run data within
Print expressions within training script
The environment in which the script should be evaluated
The encoding of the training script; see file().
Single row data frame with run flags, metrics, etc.